@@ -314,7 +314,7 @@ def alerts_list(context, active, limit, more_info, team_name, out_of_office_hour
         if 'd' in last:
             subtract_period = 'days'
         subtract_value = int(re.sub(r'[mwd]', '', last))
-        args = {subtract_period:subtract_value}
+        args = {subtract_period: subtract_value}
         subtracted_date = (pendulum.now().in_tz('Europe/Amsterdam')).subtract(**args)
         sortedlist = [x for x in sortedlist  \
                         if (pendulum.parse(x['createdAt'])).in_tz('Europe/Amsterdam') >= subtracted_date]
@@ -1556,15 +1556,15 @@ def schedules_get(context, id_, team_name):
         The json output from the API on success, None otherwise
 
     """
+    if not all([id_, team_name]):
+        raise click.UsageError(
+            "No schedule id or team name was specified. Use --id or --team_name.\n"
+        )
     if id_:
         result = context.obj['opsgenie'].get_schedules_by_id(id_)
     if team_name:
         team_schedule_name = find_team_schedule_name_by_name(team_name)  # pylint: disable=no-value-for-parameter
         result = context.obj['opsgenie'].get_schedules_by_name(team_schedule_name)
-    else:
-        raise click.UsageError(
-            "No schedule id or team name was specified. Use --id or --team_name.\n"
-        )
     print(json.dumps(result, indent=4, sort_keys=True))
 
 
